# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# suites.py - definitions of AccelerateWP feature suites

from typing import Set

from clwpos.optimization_features import (
    Feature,
    OBJECT_CACHE_FEATURE,
    SITE_OPTIMIZATION_FEATURE,
)
from dataclasses import dataclass


@dataclass
class Suite:
    """Base Suite implementation"""
    name: str
    features: Set

    @property
    def feature_set(self) -> Set[Feature]:
        """"""
        return self.features


AWPSuite = Suite(
    name='accelerate_wp',
    features={
        SITE_OPTIMIZATION_FEATURE
    })

PremiumSuite = Suite(
    name='accelerate_wp_premium',
    features={
        OBJECT_CACHE_FEATURE
    })

ALL_SUITES = {
    AWPSuite.name: AWPSuite,
    PremiumSuite.name: PremiumSuite
}

# for backward compatibility with old configs
OLD_NEW_SUITE_NAME_PAIRS = {
    'object_cache': 'accelerate_wp_premium',
    'site_optimization': 'accelerate_wp'
}
